@@ -2,6 +2,7 @@
 import io
 import json
 import pandas as pd
+import numpy as np
 
 from .api import ApiObject, api_post, api_get, api_delete
 from .common import upload_dataframe
@@ -83,6 +84,51 @@ class Model(ApiObject):
 
         return api_put(f'api/models/{self.model_id}/predictions/{prediction_id}', data = json.dumps(actual))
 
+    def derive_task(self, method = 'auto', value = None):
+        """
+        Derive task with subset of features.
+        
+        Args:
+            method: feature selection method - 'auto', 'number', 'proportion' or 'significance'.
+            value: in (0, 1) for 'proportion' and 'significance', int otherwise.
+
+        Raises:
+            RuntimeError, ValueError.
+        """
+        if method not in ('auto', 'number', 'proportion', 'significance'):
+            raise ValueError('invalid method')
+
+        feature_importance = self.results.get('feature_importance')
+
+        if not feature_importance:
+            raise RuntimeError('feature_importance is missing')
+
+        if method != 'auto':
+            if value is None:
+                raise ValueError('invalid value')
+
+            if method in ('proportion', 'significance'):
+                if value <= 0 or value >= 1:
+                    raise ValueError('value must be in (0, 1)')
+
+            if method in ('number', 'proportion'):
+                if method == 'number':
+                    n = int(value)
+                else:
+                    n = int(len(feature_importance) * value)
+
+                if n <= 0:
+                    raise ValueError('no features selected')
+                if n >= len(feature_importance):
+                    raise ValueError('all features selected')
+
+        payload = dict(method = method)
+        if method != 'auto':
+            payload['value'] = value
+
+        from .task import Task
+        return Task(api_post(f'api/models/{self.model_id}/tasks', json=payload))
+
     def _predict(self, data, prediction_method):
         if self.status != 'running':
             raise RuntimeError('status must be running')
